boss.helper - heros-boss unknown documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# boss.helper

## Attributes

`SPAM` |
`format` |
`log` |

## Classes

`Logger` | Instances of the Logger class represent a single logging channel. A

## Functions

`get_module`(path[, relative_path]) |
`get_class_by_name`(name[, relative_path]) | Resolve class by name
`file_from_url`(→ io.IOBase) | Load content from a file specified by a URL.

## Module Contents

boss.helper.get_module(path, relative_path=None)

boss.helper.get_class_by_name(name, relative_path=None)

  Resolve class by name

  Parameters:

    name – (str) “%s.%s” % (module.name, class.name)

  Returns:

    (class)

boss.helper.file_from_url(url: str) → io.IOBase

  Load content from a file specified by a URL.

  This can be every type of URL supported by pythons urllib (e.g. http://, file://, etc ). Giving the basic auth credentials in the URL in the form http://user:password@hostname:port/path is supported.

  Returns:

    file handle on the file

boss.helper.SPAM = 5

class boss.helper.Logger(name, level=NOTSET)

  Bases: `logging.Logger`

  Instances of the Logger class represent a single logging channel. A “logging channel” indicates an area of an application. Exactly how an “area” is defined is up to the application developer. Since an application can have any number of areas, logging channels are identified by a unique string. Application areas can be nested (e.g. an area of “input processing” might include sub-areas “read CSV files”, “read XLS files” and “read Gnumeric files”). To cater for this natural nesting, channel names are organized into a namespace hierarchy where levels are separated by periods, much like the Java or Python package namespace. So in the instance given above, channel names might be “input” for the upper level, and “input.csv”, “input.xls” and “input.gnu” for the sub-levels. There is no arbitrary limit to the depth of nesting.

  setLevel(level, globally=False)

    Set the logging level of this logger. level must be an int or a str.

  spam(msg, *args, **kwargs)

boss.helper.format = '%(asctime)-15s %(name)s: %(message)s'

boss.helper.log